# Table of Contents

- [business-capabilities-modeling-v3](<./business-capabilities-modeling-v3.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Modeling: Business Capabilities (Meta Model v3)](<./Modeling-Business-Capabilities-Meta-Model-v3.md>)
  - [Overview](<./Modeling-Business-Capabilities-Meta-Model-v3/Overview.md>)
  - [Resources](<./Modeling-Business-Capabilities-Meta-Model-v3/Resources.md>)
